@@ -6,7 +6,8 @@ class Index(dict):
 		resolved = Config.parameter_name_resolver.resolve(self, name)
 		if resolved is None:
 			#raise Config.exception_factory.create_input_error(name, 'Unresolved name.')
-			raise Config.exception_factory.create_internal_error(name, 'Unresolved name.')
+			#raise Config.exception_factory.create_internal_error(name, 'Unresolved name.')
+			raise AttributeError() # to comply with hasattr
 		result = self[resolved]
 		return result
 
